import request from '@/utils/request'

/**
 * 新增打印日志
 * @param data
 * @returns {*}
 */
export function addPrintLog(data) {
  return request({
    url: '/nasc/record/addPrintLog',
    method: 'post',
    data: data
  })
}

/**
 * 获取受理编号
 * @returns {*}
 */
export function getSerialNumber() {
  return request({
    url: '/nasc/record/getSerialNumber',
    method: 'get'
  })
}

/**
 * 获取受理编号并生成条形码
 * @returns {*}
 */
export function getSerialNumberBarcode() {
  return request({
    url: '/nasc/record/getSerialNumberBarcode',
    method: 'get'
  })
}

/**
 * 新增受理记录
 * @param data
 * @returns {*}
 */
export function addDealRecord(data) {
  return request({
    url: '/nasc/record/addDealRecord',
    method: 'post',
    data: data
  })
}

/**
 * 修改受理记录状态
 * @param data
 * @returns {*}
 */
export function updateDealRecordStatus(data) {
  return request({
    url: '/nasc/record/updateDealRecordStatus',
    method: 'post',
    data: data
  })
}

/**
 * 分页获取受理记录数据
 * @param query
 * @returns {*}
 */
export function listDealRecord(query) {
  return request({
    url: '/nasc/record/listDealRecord',
    method: 'get',
    params: query
  })
}

/**
 * 根据ID获取受理记录
 * @param query
 * @returns {*}
 */
export function getDealRecordById(query) {
  return request({
    url: '/nasc/record/getDealRecordById',
    method: 'get',
    params: query
  })
}

/**
 * 新增人工核验记录
 * @param data
 * @returns {*}
 */
export function addManualVerify(data) {
  return request({
    url: '/nasc/record/addManualVerify',
    method: 'post',
    data: data
  })
}

/**
 * 人工核验
 * @param data
 * @returns {*}
 */
export function updateManualVerify(data) {
  return request({
    url: '/nasc/record/updateManualVerify',
    method: 'post',
    data: data
  })
}

/**
 * 分页获取人工核验记录
 * @param query
 * @returns {*}
 */
export function listManualVerify(query) {
  return request({
    url: '/nasc/record/listManualVerify',
    method: 'get',
    params: query
  })
}

/**
 * 根据ID获取所有人工审核信息
 * @param ids
 * @returns {*}
 */
export function getManualVerifyByIds(ids) {
  return request({
    url: '/nasc/record/getManualVerifyByIds?ids=' + ids.join(),
    method: 'get'
  })
}

/**
 * 上传文件
 * @param data
 * @returns {*}
 */
export function importCertificate(data) {
  return request({
    url: '/nasc/record/importCertificate',
    method: 'post',
    data: data
  })
}

/**
 * 查询证照
 * @param query
 * @returns {*}
 */
export function listCertificate(query) {
  return request({
    url: '/nasc/record/listCertificate',
    method: 'get',
    params: query
  })
}

/**
 * 新增证书发放记录
 * @param data
 * @returns {*}
 */
export function addCertificateSend(data) {
  return request({
    url: '/nasc/record/addCertificateSend',
    method: 'post',
    data: data
  })
}

/**
 * 发放证书
 * @param data
 * @returns {*}
 */
export function sendCertificate(data) {
  return request({
    url: '/nasc/record/sendCertificate',
    method: 'post',
    data: data
  })
}

/**
 * 查询证照发放记录
 * @param query
 * @returns {*}
 */
export function listCertificateSend(query) {
  return request({
    url: '/nasc/record/listCertificateSend',
    method: 'get',
    params: query
  })
}

/**
 * 查询日志
 * @param query
 * @returns {*}
 */
export function listPrintLogList(query) {
  return request({
    url: '/nasc/record/listPrintLogList',
    method: 'get',
    params: query
  })
}
