import request from '@/utils/request'
import { parseStrEmpty } from "@/utils/ruoyi";

/**
 * 根据条件分页查询远程桌面数据列表
 * @param query
 * @returns {*}
 */
export function listVncDesktop(query) {
  return request({
    url: '/nasc/vnc/list',
    method: 'get',
    params: query
  })
}

/**
 * 根据条件查询所有远程桌面数据列表
 * @param query
 * @returns {*}
 */
export function listAllVncDesktop(query) {
  return request({
    url: '/nasc/vnc/listAll',
    method: 'get',
    params: query
  })
}

/**
 * 保存远程桌面数据信息
 * @param data
 * @returns {*}
 */
export function addVncDesktop(data) {
  return request({
    url: '/nasc/vnc',
    method: 'post',
    data: data
  })
}

/**
 * 修改远程桌面数据信息
 * @param data
 * @returns {AxiosPromise}
 */
export function updateVncDesktop(data) {
  return request({
    url: '/nasc/vnc',
    method: 'put',
    data: data
  })
}

/**
 * 批量根据ID进行删除远程桌面数据
 * @param data
 * @returns {AxiosPromise}
 */
export function delVncDesktop(id) {
  return request({
    url: '/nasc/vnc/' + id,
    method: 'delete'
  })
}

/**
 * 根据ID查询远程桌面数据信息
 * @param id
 * @returns {*}
 */
export function getVncDesktop(id) {
  return request({
    url: '/nasc/vnc/' + parseStrEmpty(id),
    method: 'get'
  })
}
